==> esup-canal-signet2-1.00-RC-1.zip: source/org/esupportail/portal/channels/CSignet2/interpreter/OperaInterpreter.java <==
/*
 * Cree le 15 nov. 2004
 *
 * TODO 
 * par cbissler
 * Centre de Ressources Informatiques 
 * Universit Henri Poincar 
 */
package org.esupportail.portal.channels.CSignet2.interpreter;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.Vector;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.esupportail.portal.channels.CSignet2.beans.BookMark;
import org.esupportail.portal.channels.CSignet2.beans.Folder;
import org.esupportail.portal.channels.CSignet2.data.DataControler;
import org.esupportail.portal.channels.CSignet2.utils.CaracteresSpeciaux;

/**
 * OperaInterpreter<br>
 * <br>
 * 
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:celine.bissler@uhp-nancy.fr">Cline Bissler</a>
 * @version 1.1 
 */
public class OperaInterpreter  implements Interpreter {
    protected static final Log log = LogFactory.getLog(DataControler.class);
    
    private String login=null;
    private String ligne_courante=null;
    private BufferedReader r=null;
    
    private int SYNT_FOLDER=1;
    private int SYNT_BOOKMARK=2;
    private int SYNT_DL=3;
    private int SYNT_FIN_DL=4;
    private int SYNT_NULL=5;
    
    private CaracteresSpeciaux carac;
    /**
     * Constructeur
     * @param input Le flux XML
     * @param login Le login de l'utilisateur
     */
    public OperaInterpreter(String login) {
        this.login=login;
        carac=new CaracteresSpeciaux();
   }
   
    /**
     * Interprete le document xml et retourne l'arborescence : 
     * le Folder root 
     * @return Le Folder root de l'arborescence  ajouter
     */
    public Folder interpreter(InputStream input) throws MalFormeException,IOException{
        Folder f= new Folder();
        f.setTitle("Chargement Opera");
        Calendar d=Calendar.getInstance();
        f.setDescription("Chargement Opera le : "+d.get(Calendar.DAY_OF_MONTH)+" - "+d.get(Calendar.MONTH)+" - "+d.get(Calendar.YEAR));
        log.info("ici 1");
        Reader br = new InputStreamReader(input,"UTF-8");//"UTF-8"
        log.info("ici 2");
        r=new BufferedReader(br);
        log.info("ici 3");
        ligne_courante="";
        int i=1;
        
     /*   int j=LireLigne();
        log.debug("LA LIGNE CRTE"+ ligne_courante +"CODE "+j);*/
        int code=SYNT_NULL;
        while ((ligne_courante!=null)){//&&(code!=SYNT_FIN_DL)
            code=LireLigne();
            if (code==SYNT_FOLDER)
            {
                f.addSubFolder(interpreterFolder(i));
                i++;
            }
            if (code==SYNT_BOOKMARK)
            {
               f.addBookMark(interpreterBookmark(i));
                i++;
            }
            
        }
        	
        br.close();
       
        return f;
    }
    
    private int LireLigne()throws IOException{
        log.info("CSignet2 - OperaInterpreter::LireLigne()");
        
        ligne_courante = r.readLine();
        log.debug("CSignet2 - OperaInterpreter::LireLigne() la ligne : "+ligne_courante);
        
        if (ligne_courante!=null){
            if (ligne_courante.indexOf("#FOLDER")!=-1)
	            return SYNT_FOLDER;
	        else if (ligne_courante.indexOf("#URL")!=-1)
	            return SYNT_BOOKMARK;
	        else if (ligne_courante.equals("-"))
	            return SYNT_FIN_DL;
	        else
	            return SYNT_NULL;
        }
        else
            return SYNT_NULL;
    }
    
    /**
     * Interprte un rpertoire 
     * @param el Element XML
     * @param ordre Ordre dans lequel il est trouv de dans lequel il apparatra dans l'arborescence
     * @return Le Folder correspondant
     */
    private Folder interpreterFolder(int ordre) throws MalFormeException,IOException{
        log.info("CSignet2 - OperaInterpreter::interpreterFolder()");
        Folder f=new Folder();
          
        Collection les_book=new Vector();
        Collection les_fold=new Vector();
        
        f.setB_modif(true);
        f.setLogin(login);
        f.setId_group("aucun");
        f.setB_root(false);
        f.setOrder(ordre);
        Date d=new Date();
        f.setTitle(getTitreFolder());
       // f.setDescription("Chargement Opera le : "+d.toString());
        if ((f.getTitle()==null)||(f.getTitle().compareTo("")==0))
            throw new MalFormeException("Il n'y pas de titre de dossier ");
       
        int i=1;
        int code=SYNT_NULL;
        while ((ligne_courante!=null)&&(code!=SYNT_FIN_DL)){
            code=LireLigne();
            if (code==SYNT_FOLDER)
            {
                f.addSubFolder(interpreterFolder(i));
                i++;
            }
            if (code==SYNT_BOOKMARK)
            {
                f.addBookMark(interpreterBookmark(i));
                i++;
            }
            
        }
        f.setTitle(carac.convertirCaracXML(f.getTitle()));
        
      return f;
      
    }
    /**
     * Interprte un bookmark
     * @param el Element XML
     * @param ordre Ordre dans lequel il est trouv de dans lequel il apparatra dans l'arborescence
     * @return Le BookMark correspondant
     */
    private BookMark interpreterBookmark(int ordre)throws MalFormeException,IOException{
        log.info("CSignet2 - OperaInterpreter::interpreterBookmark()");
        
        BookMark f=new BookMark();
        
        f.setB_modif(true);
        f.setLogin(login);
        f.setId_group("aucun");
        f.setB_root(false);
        f.setOrder(ordre);
        Date d=new Date();
      //  f.setDescription("Chargement Opera le : "+d.toString());
        f.setTitle(getTitreBookMark());
        f.setUrl(getUrlBookMark());
        if ((f.getTitle()==null)||(f.getTitle().compareTo("")==0))
            throw new MalFormeException("Il n'y pas de titre au Signet ");
        if ((f.getUrl()==null)||(f.getUrl().compareTo("")==0))
            throw new MalFormeException("Il n'y pas d'URL au Signet ");
        f.setTitle(carac.convertirCaracXML(f.getTitle()));
        f.setUrl(carac.convertirCaracXMLURL(f.getUrl()));
        return f;
    }
    private String getTitreFolder()throws MalFormeException,IOException{
        log.info("CSignet2 - OperaInterpreter::getTitreFolder()");
        
        String titre=null;
       // String ligne="";
        boolean bool=false;
        //BufferedReader rl=r;
        int code = LireLigne();
        while ((ligne_courante!=null)&&(!bool)&&(code==SYNT_NULL))
            {
             
            if (ligne_courante.indexOf("NAME=")!=-1)
            {
                int deb=ligne_courante.indexOf("NAME=");
                titre=ligne_courante.substring(deb+5);
                bool=true;
                titre=carac.convertirAccentue(titre);
            }
            else
                code= LireLigne();
        }
        log.debug("CSignet2 - OperaInterpreter::getTitreFolder() retourne : "+titre);
        
        return titre;
    }
    private String getTitreBookMark()throws MalFormeException,IOException{
        log.info("CSignet2 - OperaInterpreter::getTitreBookMark()");
        
        String titre=null;
        
        boolean bool=false;
       
        int code = LireLigne();
        while ((ligne_courante!=null)&&(!bool)&&(code==SYNT_NULL))
            {
             
            if (ligne_courante.indexOf("NAME=")!=-1)
            {
                int deb=ligne_courante.indexOf("NAME=");
                titre=ligne_courante.substring(deb+5);
                bool=true;
                titre=carac.convertirAccentue(titre);
            }
            else
                code= LireLigne();
        }
        
        log.debug("CSignet2 - OperaInterpreter::getTitreBookMark() retourne : "+titre);
        
        return titre;
    }
    private String getUrlBookMark()throws MalFormeException,IOException{
        log.info("CSignet2 - OperaInterpreter::getUrlBookMark()");
                
        String url=null;
       
        boolean bool=false;
       
        int code = LireLigne();
        while ((ligne_courante!=null)&&(!bool)&&(code==SYNT_NULL))
            {
             
            if (ligne_courante.indexOf("URL=")!=-1)
            {
                int deb=ligne_courante.indexOf("URL=");
                url=ligne_courante.substring(deb+4);
                bool=true;
            }
            else
                code= LireLigne();
        }
        log.debug("CSignet2 - OperaInterpreter::getUrlBookMark() retourne : "+url);
        
        
        return url;
    }
}

==> esup-canal-signet2-1.06-RC-1.zip: source/org/esupportail/portal/channels/CSignet2/interpreter/OperaInterpreter.java <==
/*
 * Cree le 15 nov. 2004
 *
 * TODO 
 * par cbissler
 * Centre de Ressources Informatiques 
 * Universit Henri Poincar 
 */
package org.esupportail.portal.channels.CSignet2.interpreter;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.Vector;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.esupportail.portal.channels.CSignet2.beans.BookMark;
import org.esupportail.portal.channels.CSignet2.beans.Folder;
import org.esupportail.portal.channels.CSignet2.data.DataControler;
import org.esupportail.portal.channels.CSignet2.utils.CaracteresSpeciaux;

/**
 * OperaInterpreter<br>
 * <br>
 * 
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:celine.bissler@uhp-nancy.fr">Cline Bissler</a>
 * @version 1.1 
 */
public class OperaInterpreter  implements Interpreter {
    protected static final Log log = LogFactory.getLog(DataControler.class);
    
    private String login=null;
    private String ligne_courante=null;
    private BufferedReader r=null;
    
    private int SYNT_FOLDER=1;
    private int SYNT_BOOKMARK=2;
    private int SYNT_DL=3;
    private int SYNT_FIN_DL=4;
    private int SYNT_NULL=5;
    
    private CaracteresSpeciaux carac;
    /**
     * Constructeur
     * @param input Le flux XML
     * @param login Le login de l'utilisateur
     */
    public OperaInterpreter(String login) {
        this.login=login;
        carac=new CaracteresSpeciaux();
   }
   
    /**
     * Interprete le document xml et retourne l'arborescence : 
     * le Folder root 
     * @return Le Folder root de l'arborescence  ajouter
     */
    public Folder interpreter(InputStream input) throws MalFormeException,IOException{
        Folder f= new Folder();
        f.setTitle("Chargement Opera");
        Calendar d=Calendar.getInstance();
        f.setDescription("Chargement Opera le : "+d.get(Calendar.DAY_OF_MONTH)+" - "+d.get(Calendar.MONTH)+" - "+d.get(Calendar.YEAR));
        if (log.isDebugEnabled()) log.debug("ici 1");
        Reader br = new InputStreamReader(input,"UTF-8");//"UTF-8"
        if (log.isDebugEnabled()) log.debug("ici 2");
        r=new BufferedReader(br);
        if (log.isDebugEnabled()) log.debug("ici 3");
        ligne_courante="";
        int i=1;
        
     /*   int j=LireLigne();
        if (log.isDebugEnabled()) log.debug("LA LIGNE CRTE"+ ligne_courante +"CODE "+j);*/
        int code=SYNT_NULL;
        while ((ligne_courante!=null)){//&&(code!=SYNT_FIN_DL)
            code=LireLigne();
            if (code==SYNT_FOLDER)
            {
                f.addSubFolder(interpreterFolder(i));
                i++;
            }
            if (code==SYNT_BOOKMARK)
            {
               f.addBookMark(interpreterBookmark(i));
                i++;
            }
            
        }
        	
        br.close();
       
        return f;
    }
    
    private int LireLigne()throws IOException{
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::LireLigne()");
        
        ligne_courante = r.readLine();
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::LireLigne() la ligne : "+ligne_courante);
        
        if (ligne_courante!=null){
            if (ligne_courante.indexOf("#FOLDER")!=-1)
	            return SYNT_FOLDER;
	        else if (ligne_courante.indexOf("#URL")!=-1)
	            return SYNT_BOOKMARK;
	        else if (ligne_courante.equals("-"))
	            return SYNT_FIN_DL;
	        else
	            return SYNT_NULL;
        }
        else
            return SYNT_NULL;
    }
    
    /**
     * Interprte un rpertoire 
     * @param el Element XML
     * @param ordre Ordre dans lequel il est trouv de dans lequel il apparatra dans l'arborescence
     * @return Le Folder correspondant
     */
    private Folder interpreterFolder(int ordre) throws MalFormeException,IOException{
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::interpreterFolder()");
        Folder f=new Folder();
          
        Collection les_book=new Vector();
        Collection les_fold=new Vector();
        
        f.setB_modif(true);
        f.setLogin(login);
        f.setId_group("aucun");
        f.setB_root(false);
        f.setOrder(ordre);
        Date d=new Date();
        f.setTitle(getTitreFolder());
       // f.setDescription("Chargement Opera le : "+d.toString());
        if ((f.getTitle()==null)||(f.getTitle().compareTo("")==0))
            throw new MalFormeException("Il n'y pas de titre de dossier ");
       
        int i=1;
        int code=SYNT_NULL;
        while ((ligne_courante!=null)&&(code!=SYNT_FIN_DL)){
            code=LireLigne();
            if (code==SYNT_FOLDER)
            {
                f.addSubFolder(interpreterFolder(i));
                i++;
            }
            if (code==SYNT_BOOKMARK)
            {
                f.addBookMark(interpreterBookmark(i));
                i++;
            }
            
        }
        f.setTitle(carac.convertirCaracXML(f.getTitle()));
        
      return f;
      
    }
    /**
     * Interprte un bookmark
     * @param el Element XML
     * @param ordre Ordre dans lequel il est trouv de dans lequel il apparatra dans l'arborescence
     * @return Le BookMark correspondant
     */
    private BookMark interpreterBookmark(int ordre)throws MalFormeException,IOException{
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::interpreterBookmark()");
        
        BookMark f=new BookMark();
        
        f.setB_modif(true);
        f.setLogin(login);
        f.setId_group("aucun");
        f.setB_root(false);
        f.setOrder(ordre);
        Date d=new Date();
      //  f.setDescription("Chargement Opera le : "+d.toString());
        f.setTitle(getTitreBookMark());
        f.setUrl(getUrlBookMark());
        if ((f.getTitle()==null)||(f.getTitle().compareTo("")==0))
            throw new MalFormeException("Il n'y pas de titre au Signet ");
        if ((f.getUrl()==null)||(f.getUrl().compareTo("")==0))
            throw new MalFormeException("Il n'y pas d'URL au Signet ");
        f.setTitle(carac.convertirCaracXML(f.getTitle()));
        f.setUrl(carac.convertirCaracXMLURL(f.getUrl()));
        return f;
    }
    private String getTitreFolder()throws MalFormeException,IOException{
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::getTitreFolder()");
        
        String titre=null;
       // String ligne="";
        boolean bool=false;
        //BufferedReader rl=r;
        int code = LireLigne();
        while ((ligne_courante!=null)&&(!bool)&&(code==SYNT_NULL))
            {
             
            if (ligne_courante.indexOf("NAME=")!=-1)
            {
                int deb=ligne_courante.indexOf("NAME=");
                titre=ligne_courante.substring(deb+5);
                bool=true;
                titre=carac.convertirAccentue(titre);
            }
            else
                code= LireLigne();
        }
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::getTitreFolder() retourne : "+titre);
        
        return titre;
    }
    private String getTitreBookMark()throws MalFormeException,IOException{
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::getTitreBookMark()");
        
        String titre=null;
        
        boolean bool=false;
       
        int code = LireLigne();
        while ((ligne_courante!=null)&&(!bool)&&(code==SYNT_NULL))
            {
             
            if (ligne_courante.indexOf("NAME=")!=-1)
            {
                int deb=ligne_courante.indexOf("NAME=");
                titre=ligne_courante.substring(deb+5);
                bool=true;
                titre=carac.convertirAccentue(titre);
            }
            else
                code= LireLigne();
        }
        
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::getTitreBookMark() retourne : "+titre);
        
        return titre;
    }
    private String getUrlBookMark()throws MalFormeException,IOException{
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::getUrlBookMark()");
                
        String url=null;
       
        boolean bool=false;
       
        int code = LireLigne();
        while ((ligne_courante!=null)&&(!bool)&&(code==SYNT_NULL))
            {
             
            if (ligne_courante.indexOf("URL=")!=-1)
            {
                int deb=ligne_courante.indexOf("URL=");
                url=ligne_courante.substring(deb+4);
                bool=true;
            }
            else
                code= LireLigne();
        }
        if (log.isDebugEnabled()) log.debug("CSignet2 - OperaInterpreter::getUrlBookMark() retourne : "+url);
        
        
        return url;
    }
}
